% A simple, but inefficient, implementation of the Separatrix Algorithm
%
% Separatrix Demo, Institute for Disease Modeling, May 2014

clear, close all

ONE_DIMENSIONAL_EXAMPLE = 1;	TWO_DIMENSIONAL_EXAMPLE = 2;

% Change the following line to select one of the above options:
EXAMPLE = TWO_DIMENSIONAL_EXAMPLE;

%% Parameters to configure the Separatrix Algorithm
% These parameters are for the 1D example, will change below for 2D example
params = struct(...
	... % Choose the sigmoidal model:
	'Model',						'SigmoidalModel', ...
	...
	... % Number of iterations before stopping:
	'Number_Of_Iterations',			10, ...
	...
	... % Random number generator seed
	'Random_Seed',					1, ...
	...
	... % Tempory working directory:
	'Output_Dir',					'OutputDir', ...
	...
	... % Target isocline of success probability function:
	'Interest_Level',				0.7, ...
	...
	... % Number of samples for first iteration:
	'Num_Initial_Samples',			50, ...
	...
	... % Number of samples to add per subsequent iteration:
	'Num_Next_Samples',				50, ...
	...
	... % Number of "test points":
	'Num_Test_Points',				100, ...
	...
	... % Number of "candidate points":
	'Num_Candidates_Points',		200, ...
	...
	... % Stdev of gaussian kernel for effective number of samples (Nhat):
	'Scale_Model_Sigma',			0.02, ...
	...
	... % Bandwidth scaling for density estimation:
	'h_rho',						0.3, ...
	...
	... % Coeff for choosing num neighbors in density KNN:
	'c_rho',						0.5, ...
	...
	... % Exponent for choosing num neighbors in density KNN:
	'gamma_rho',					0.8, ...
	...
	... % Coeff for choosing num neighbors in inference KNN:
	'c_inference',					4, ...
	...
	... % Exponent for choosing num neighbors in inference KNN:
	'Gamma_Inference',				0.8, ...
	...
	... % Minimum number of neighbors for density and inference:
	'Min_Neighbors_for_KNN',		3, ...
	...
	... % Constant fraction of samples by LHS:
	'Fraction_LHS',					0, ...
	...
	... % Use some LHS initially to aid in exploration by limiting the 
	... % number of next points that will be determined by igBDOE.
	'Max_Fraction_igBDOE',			0.25, ...
	...
	... % Lower bounds on inference bandwidth:
	'min_g',						0, ...
	...
	... % Upper bounds on inference bandwidth:
	'max_g',						1, ...
	...
	... % Resolution of MCMC for candidate and test points:
	'MCMC_Resolution',				1000, ...
	...
	... % Number of MCMC iterations:
	'MCMC_Num_Iterations',			2, ...
	...
	... % Stdev of Gaussian blur to apply post-MCMC:
	'Blur_Sigma',					0.02, ...
	...
	... % Reolution of fixed grid for visualization:
	'Inference_Grid_Resolution',	100 ...
);

if EXAMPLE == TWO_DIMENSIONAL_EXAMPLE
	% Changes for 2-D Example
	params.Model = 'tanhModel';
	params.Number_Of_Iterations = 20;
	params.Inference_Grid_Resolution = 20;
	params.Interest_Level = 0.6;
	params.Scale_Model_Sigma = 0.05;
	params.gamma_rho = 0.67;
	params.Gamma_Inference = 0.67;
end

% Now run Separatrix with these params
SeparatrixDemo(params);
