% Sigmoidal model
%
% Separatrix Demo, Institute for Disease Modeling, May 2014

classdef SigmoidalModel < ISeparatrixModel
	
	properties (SetAccess = protected)
		myrng
	end
	
	methods
		function obj = SigmoidalModel(config, varargin)
			obj = obj@ISeparatrixModel(config);	% Sets config
			obj.Initialize(varargin{:});
		end
		
		function Initialize(obj, varargin)
			obj.myrng = RandStream('mt19937ar','seed',obj.config.RandomSeed);
			
			obj.Model_Name = class(obj);
			obj.Parameter_Names = {'Parameter x'};
			obj.Parameter_Ranges =  { struct('min',0,'max',1) };
		end
		
		function Outcomes = Sample(obj, Points)
			Outcomes = rand(obj.myrng, size(Points,1),1) < obj.Truth(Points);
		end
		
		function Separatrix = TrueSeparatrix(obj, interestLevel)
			Separatrix = 1/10*atanh(2*interestLevel-1)+0.6;
		end
		
		function Probability = Truth(obj, points)
			if(size(points,2) == 1)		% 1D
				Probability = 1/2*(tanh(10*(points-0.6))+1);
				return
			end
			disp('SinusoidalModel is only compatible with 1D input data');
			Probability = [];
		end
	end
end