% Plot separatrix inference for 1D
%
% Separatrix Demo, Institute for Disease Modeling, May 2014

function plotInference1D(inference_x, sample_x, new_sample_x, sample_y, new_sample_y, a, b, ParameterRanges, true_separatrix, params)

PMFBinEdges = linspace(0,1,100)';
PMFBinCenters = PMFBinEdges(1:end-1) + (PMFBinEdges(2) - PMFBinEdges(1))/2;

% Shaded PFM
pdf = zeros(99, params.Inference_Grid_Resolution);
for j = 1:params.Inference_Grid_Resolution
	tmp = betainc( PMFBinEdges(2:end), a(j), b(j));
	pdf(:, j) = [tmp(1); diff(tmp)];
end

[xx,yy] = meshgrid(inference_x, (PMFBinCenters-PMFBinCenters(1)) / (PMFBinCenters(end)-PMFBinCenters(1)));
tri = delaunay(xx,yy);
trisurf(tri,xx,yy,pdf, 'edgecolor', 'none');
colorbar
shading interp
hold on

h_mean = plot3(inference_x, a./(a+b), 1.1*ones(size(inference_x)), 'k:', 'linewidth', 2, 'DisplayName', 'Mean');
h_mode = plot3(inference_x, (a-1)./(a+b-2), 1.1*ones(size(inference_x)), 'k-', 'linewidth', 2, 'DisplayName', 'Mode');

h_separatrix = plot3(true_separatrix*ones(1,2), [0 1], 1.1*ones(1,2), 'm-', 'linewidth', 2, 'DisplayName', 'True Separatrix');

inds = find(sample_y);
h_success = plot3( sample_x(inds), 1.05*ones(length(inds),1), 1.1*ones(length(inds),1), 'k+', 'markersize', 5, 'DisplayName', 'Success'); hold on
inds = find(sample_y == 0);
h_fail = plot3( sample_x(inds), -0.05*ones(length(inds),1), 1.1*ones(length(inds),1), 'ko', 'DisplayName', 'Fail');

h_new_success = [];	h_new_fail = [];
if ~isempty(new_sample_y)
	inds = find(new_sample_y);
	h_new_success = plot3( new_sample_x(inds), 1.05*ones(length(inds),1), 1.1*ones(length(inds),1), 'r+', 'markersize', 5, 'DisplayName', 'New Success');
	inds = find(new_sample_y == 0);
	h_new_fail = plot3( new_sample_x(inds), -0.05*ones(length(inds),1), 1.1*ones(length(inds),1), 'ro', 'markersize', 5, 'DisplayName', 'New Fail');
end

% 	h_model = plot3(xUnNormalized, Model.Truth(xUnNormalized), 1.1*ones(size(xUnNormalized)), 'k--', 'linewidth', 2);

h_interestLevel = plot3( [ParameterRanges{1}.min ParameterRanges{1}.max], params.Interest_Level*ones(1,2), 1.05*ones(1,2), 'c-', 'linewidth', 2, 'DisplayName', 'Interest Level');

view(2);

xlabel('x')
ylabel('Probability Density');
ylim([-.10 1.10]);
legend([h_success,h_fail,h_new_success,h_new_fail, h_separatrix, h_interestLevel, h_mean, h_mode], 'Location', 'EastOutside')

end