% Plot separatrix inference for 2D
%
% Separatrix Demo, Institute for Disease Modeling, May 2014

function plotInference2D(inference_x, sample_x, new_sample_x, sample_y, new_sample_y, a, b, ParameterRanges, true_separatrix, params)

%% Plot the true and estimated separatrix
subplot(3,3,[1:2 4:5 7:8])

dt = delaunay(inference_x(:,1), inference_x(:,2));
z = (a-1)./(a+b-2);	% MODE
hs = trisurf(dt, inference_x(:,1), inference_x(:,2), z);
hold on

zinterp = scatteredInterpolant(inference_x, z);
[xx,yy] = meshgrid(linspace(ParameterRanges{1}.min, ParameterRanges{1}.max, 1000), ...
	linspace(ParameterRanges{2}.min, ParameterRanges{2}.max, 1000));

h_true = plot3( true_separatrix(:,1), true_separatrix(:,2), ones(size(true_separatrix(:,1))), '--', 'color', 0.5*ones(3,1), 'linewidth', 2);
[~,h_estimate] = contour3(xx, yy, zinterp(xx,yy), params.Interest_Level*ones(2,1), 'k-');
set(h_estimate, 'linewidth', 2);

xlim([ParameterRanges{1}.min ParameterRanges{1}.max]);	ylim([ParameterRanges{2}.min ParameterRanges{2}.max]);

set(hs, 'edgecolor', 'none');
view(2)
shading interp
colorbar
axis square

legend([h_true, h_estimate(1)], 'True', 'Estimate', 'Location', 'SouthOutside')
xlabel('x'); ylabel('y');
title('Mode of Success Probability')

%% Plot the inference variance
subplot(3,3,3)
hs = trisurf(dt, inference_x(:,1), inference_x(:,2), a.*b./((a+b).^2 .* (a+b+1)) );	% Variance
hold on

h_true = plot3( true_separatrix(:,1), true_separatrix(:,2), ones(size(true_separatrix(:,1))), '--', 'color', 0.5*ones(3,1), 'linewidth', 2);
[~,h_estimate] = contour3(xx, yy, zinterp(xx,yy), params.Interest_Level*ones(2,1), 'k-');
set(h_estimate, 'linewidth', 2);

xlim([ParameterRanges{1}.min ParameterRanges{1}.max]);	ylim([ParameterRanges{2}.min ParameterRanges{2}.max]);

set(hs, 'edgecolor', 'none');
view(2)
shading interp
% colorbar
axis square

% legend([h_true, h_estimate(1)], 'True', 'Estimate', 'Location', 'SouthOutside')
xlabel('x'); ylabel('y');
title('Variance')

%% Plot the samples
subplot(3,3,[6 9])

success = sample_y > 0;	% Previous samples
fail = sample_y < 1;
h_success = plot3(sample_x(success, 1), sample_x(success, 2), 1.25*ones(sum(success), 1), 'k+', 'DisplayName', 'Success'); hold on
h_fail = plot3(sample_x(fail, 1), sample_x(fail, 2), 1.25*ones(sum(fail), 1),  'ko', 'DisplayName', 'Fail');

h_new_success = [];
h_new_fail = [];
if ~isempty(new_sample_y)
	new_success = new_sample_y > 0;	% New samples
	new_fail = new_sample_y < 1;
	h_new_success = plot3(new_sample_x(new_success, 1), new_sample_x(new_success, 2), 1.25*ones(sum(new_success), 1),  'r+', 'DisplayName', 'New Success');
	h_new_fail = plot3(new_sample_x(new_fail, 1), new_sample_x(new_fail, 2), 1.25*ones(sum(new_fail), 1),  'ro', 'DisplayName', 'New Fail');
end

xlim([ParameterRanges{1}.min ParameterRanges{1}.max]);	ylim([ParameterRanges{2}.min ParameterRanges{2}.max]);

view(2);
axis square

legend('Location', 'SouthOutside')
xlabel('x'); ylabel('y');
title('Samples')

end