% Tanh model
%
% Separatrix Demo, Institute for Disease Modeling, May 2014

classdef tanhModel < ISeparatrixModel

	properties (SetAccess = protected)
		myrng
		mx = 10;
		bx = 0.5;
		my = 3;
		by = 0.3;
		EvaluationPoints = [];
	end

	methods
		function obj = tanhModel(config, varargin)
			obj = obj@ISeparatrixModel(config);	% Sets config
			obj.Initialize(varargin{:});
		end
		
		function Initialize(obj, varargin)
			obj.myrng = RandStream('mt19937ar','seed',obj.config.RandomSeed);
			
			obj.Model_Name = class(obj);
			obj.Parameter_Names = {'Parameter x', 'Parameter y'};
			obj.Parameter_Ranges =  { struct('min',0,'max',1) struct('min',0,'max',1) };
		end

		function Outcomes = Sample(obj, Points)
			Outcomes = rand(obj.myrng,size(Points,1),1) < obj.Truth(Points);
		end
		
		function Probability = Truth(obj, points)
			x = points(:,1);
			y = points(:,2);

			Probability = (tanh(obj.mx*(x-obj.bx))+1).*(tanh(obj.my*(y-obj.by))+1)/4;
		end
		
		function true_separatrix = TrueSeparatrix(obj, iso)
			% Use contour3 to extract the separatrix
			[xx,yy] = meshgrid(linspace(obj.Parameter_Ranges{1}.min, obj.Parameter_Ranges{1}.max, 30), ...
				linspace(obj.Parameter_Ranges{2}.min, obj.Parameter_Ranges{2}.max, 30));
			pts2D = [xx(:), yy(:)];
			zinterp = scatteredInterpolant(pts2D, obj.Truth(pts2D));
			
			[xx,yy] = meshgrid(linspace(obj.Parameter_Ranges{1}.min, obj.Parameter_Ranges{1}.max, 1000), ...
				linspace(obj.Parameter_Ranges{2}.min, obj.Parameter_Ranges{2}.max, 1000));
			h = figure(235235); clf;
			[true_separatrix, ~] = contour3(xx, yy, zinterp(xx,yy), iso*ones(2,1));
			true_separatrix = true_separatrix';
			close(h)
		end

		function OverlayIsocline(obj, h, iso)
			pts = linspace(0,1,30);
			[xx,yy] = meshgrid(pts, pts);
			set(0, 'currentfigure', h); hold on;
			[~,hlines] = contour3(xx, yy, reshape(obj.Truth([xx(:),yy(:)]),30,30), iso*ones(2,1), 'k--');
			set(hlines, 'linewidth', 2);
			set(hlines, 'zdata', get(hlines, 'zdata') + 1);
		end
	end
end